\encoding{latin1}
\name{variodis}
\alias{variodis}
\alias{variodis.default}
\alias{variodis.formula}
\alias{print.variodis}
\alias{plot.variodis}
\alias{summary.variodis}
\title{Variograms of dissimilarity (beta diversity).}
\description{
 'variodis' performs variograms of beta diversity in three common diversity
     metrics (species richness, Simpson diversity and Shannon
     information) from dissimilarity matrices.
}
\usage{
##default matrix interface
variodis(Y, X = NULL, Z = NULL, coords, breaks = "Sturges", test = TRUE, nrepet = 999, alpha = 0.01)
##formula interface
variodis(formula,data,coords, breaks = "Sturges", test = TRUE, nrepet = 999, alpha = 0.01)
summary(variodis.object)
}
\arguments{
  \item{Y}{an abundance matrix with sites as rows and species as columns.}
  \item{X}{a optional constraining matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
  \item{Z}{a optional conditioning matrix of Instrumental Variables, or a factor partitioning the rows of Y into classes (see details).}
  \item{formula}{specific model formula where the left hand side gives the dependent variables (Y), right hand side gives the constraining variables (X), and conditioning variables (Z) can be given within a special function 'Condition' (see details).}
  \item{coords}{a matrix of (x,y) sites coordinates.}
  \item{breaks}{either a predefine character string ("Sturges" or "Log") or a numeric vector giving bounds of the distance intervals to define the variograms binning (see details).}
  \item{test}{a logical value indicating whether distance permutation test should be performed.}
  \item{nrepet}{if test is TRUE, an integer indicating the number of distance permutations to be performed.}
  \item{alpha}{significant level of the bilateral confidence interval.}
  \item{variodis.object}{an object of class 'div variodis'.}

}
\details{
In matrix interface, 'Y' is typically a site-by-species abundance matrix. If both other matrices are omitted, the function computes variograms of dissimilarity among the rows of Y. If 'X' is supplied, variograms of dissimilarity are computed among the rows of Yest, i.e. table Y fitted with respect to X, a matrix or factor of independent variables. If 'Z' is supplied, its effect is removed, so that the function computes variograms of dissimilarity either between the rows of Yres, i.e. the residuals of Y fitted with respect to Z ('X' is not supplied) or between the rows of Yres fitted with respect to X (effect of Z removed).

In formula interface, the model can be defined using a specific model 'formula' similar to the one used in cca{vegan}. The left hand side defines the 'Y' dependent variables. The right hand side defines the constraining 'X' variables and can include a special term 'Condition' for conditioning variables 'Z', so that 'dissim(Y~X+Condition(Z))' is equivalent to 'dissim(Y,X,Z)' (see examples).
 
Bounds of the distance intervals for the variograms binning in 'breaks' can be defined:
 
 "automatically" using a predefined character string: "Sturges" computes the number of distance intervals and their length from the data using function nclass.Sturges{graphics}; "Log" computes a log-transformed version of 'Sturges'.
 
 "manually" by a numeric vector generated for example using fonction seq{base} (see Examples).
}
\value{
 'variodis' returns an object of class 'div variodis', so that 'print.div.variodis' and 'plot.div.variodis' and 'summary.div.variodis' are the corresponding printing, plotting and summary functions. An object of class 'div variodis' is a list with the following components: 
\item{$richness}{variogram of dissimilarity in the richness metric.}
\item{$Shannon}{variogram of dissimilarity in the Shannon metric.}
\item{$Simpson}{variogram of dissimilarity in the Simpson metric.}
\item{$h}{distance corresponding to the center of the bins defined by argument 'breaks'.}
\item{$w}{bins' weights.}

'summary.div.variodis' returns an object of class 'summary.variodis', i.e. a data.frame of diversity components corresponding to terms of the model.
}
\references{Couteron, P. & Plissier, R. 2004. Additive apportioning of species diversity: towards more sophisticated models and analyses. Oikos, 107(1): 215-221.}
\author{Raphael.Pelissier@ird.fr}
\seealso{\link{nclass.Sturges}, \link{spadis}}
\examples{
data(CFI)

##performs variograms of dissimilarity between the rows of 'CFI$tab'
##v1<-variodis(tab,xy) # allowing distance permutations will take a little time
v1<-variodis(CFI$tab,coords=CFI$xy,test=FALSE)
v1
summary(v1)
plot(v1)
##the same using a regular sequence of 2 km-distance intervals
v2<-variodis(CFI$tab,coords=CFI$xy,breaks=seq(0,12,2),test=FALSE) 

##performs variograms of dissimilarity between the rows of 'CFI$tab' predicted by 'CFI$topo'
vtopo<-variodis(CFI$tab~CFI$topo,coords=CFI$xy,test=FALSE)
summary(vtopo)
plot(vtopo)

##performs variograms of dissimilarity between the rows of 'CFI$tab' once removed the effects of 'CFI$topo'
vtopo.res<-variodis(CFI$tab~Condition(CFI$topo),coords=CFI$xy,test=FALSE)
summary(vtopo.res)
plot(vtopo.res)

##compute variograms of dissimilarity between the rows of 'CFI$tab' predicted by CFI$topo, once removed the effect of 'topo2', i.e. within the levels of 'topo2'
topo2<-CFI$topo
levels(topo2)[1:7]<-"uplands"
levels(topo2)[-1]<-"bottomlands"
vtopo.within<-variodis(CFI$tab~CFI$topo+Condition(topo2),coords=CFI$xy,test=FALSE)
summary(vtopo.within)
plot(vtopo.within)
}

